#!/bin/sh

ln -s /usr/share/javascript/backbone
ln -s /usr/share/javascript/underscore
ln -s /usr/share/javascript/jquery
ln -s /usr/share/javascript/json
ln -s /usr/share/twitter-bootstrap/files twbs
