# -*- coding: utf-8 -*-
username0 = 'guest'
email0 = 'guest@example.org'
password0 = 'passw0rd'
username1 = 'guest1'
email1 = 'guest1@example.org'
password1 = 'passw1rd'
username2 = 'admin0'
email2 = 'admin0@example.org'
password2 = 'passw2rd'
url0 = 'http://dummy.example.org'
title0 = 'dummy タイトル'
description0 = 'This description is dummy sentense.'
url1 = 'http://dummy1.example.org'
title1 = 'dummy タイトル1'
description1 = 'This description is dummy1 sentense.'
url2 = 'http://dummy2.example.org'
title2 = 'dummy タイトル2'
description2 = 'This description is dummy2 sentense.'
category0 = 'test 0'
category1 = 'テスト 0'
category2 = 'test 1 abc'
tag0 = 'test 0'
tag1 = 'テスト 0'
tag2 = 'test 1 abc'
